@@ -12,6 +12,7 @@ namespace SebastianBergmann\Comparator;
 use function assert;
 use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\MockObject\Generator\Generator;
 use PHPUnit\Framework\MockObject\MockObject;
@@ -22,6 +23,7 @@ use stdClass;
 #[UsesClass(Comparator::class)]
 #[UsesClass(ComparisonFailure::class)]
 #[UsesClass(Factory::class)]
+#[Small]
 final class MockObjectComparatorTest extends TestCase
 {
     private MockObjectComparator $comparator;
