@@ -11,6 +11,7 @@ namespace SebastianBergmann\Comparator;
 
 use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
 use stdClass;
@@ -19,6 +20,7 @@ use stdClass;
 #[UsesClass(Comparator::class)]
 #[UsesClass(ComparisonFailure::class)]
 #[UsesClass(Factory::class)]
+#[Small]
 final class ObjectComparatorTest extends TestCase
 {
     private ObjectComparator $comparator;
